#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recv
version:              0.1.1
visibility:           public
id:                   recv-0.1.1-JHOpQBMWacCIONlknftyvf
key:                  recv-0.1.1-JHOpQBMWacCIONlknftyvf
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Efficient network recv
description:          Network recv based on buffer pools
category:             Network
abi:                  4e1f1591ccf18d3bfa6f8995283dc91d
exposed:              True
exposed-modules:      Network.Socket.BufferPool
hidden-modules:
    Network.Socket.BufferPool.Buffer Network.Socket.BufferPool.Recv
    Network.Socket.BufferPool.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/recv-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/recv-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/recv-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recv
hs-libraries:         HSrecv-0.1.1-JHOpQBMWacCIONlknftyvf
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-9nB9sbnLDjyBVIWLW7TDGb

haddock-interfaces:   /usr/share/doc/haskell-recv/html/recv.haddock
haddock-html:         /usr/share/doc/haskell-recv/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

